---
title: "Chaos Labs <> Aave Risk Management Service Renewal"
author: "Aave Chan Initiative"
discussions: "https://governance.aave.com/t/arfc-chaos-labs-aave-risk-management-service-renewal/19306"
snapshot: "https://snapshot.org/#/aave.eth/proposal/0xa8ec5cf2568691144861b38af1b2cef4f95d33d0912fea28438132cabf4b6c28"
---

## Simple Summary

Chaos Labs proposes to renew our engagement with the Aave DAO. We will provide our full suite of risk management products and services, covering all of Aave, including V2, V3, and GHO, across all current and future deployments.

Our current annual engagement is set to end on November 13th, 2024.

## **Background**

In November 2022, Chaos Labs formally joined the Aave DAO as a service provider specializing in risk management and parameter optimization.

During this time, we have consistently demonstrated our unwavering dedication to the DAO, covering all aspects of the protocol across all deployments and providing the community with proactive risk parameter recommendations alongside reactive analyses and risk-mitigating strategies in light of significant market events. Chaos Labs has initiated over 230 ARFCs and posts, and actively engaged with more than 770 posts, including parameter optimization, onboarding of new assets and new deployments, deprecation of V2 and migration to V3, GHO growth, and community support during major market events.

Throughout our engagement, the protocol incurred minimal bad debt, even during significant market events, including those on August 6, 2024, which resulted in zero bad debt.

:bulb: A comprehensive summary of Chaos Labs’ activities over the past contract year is available in our monthly community updates here. [Chaos Labs - Monthly Community Update](https://governance.aave.com/t/chaos-labs-monthly-community-update/11174/12)

## Highlighted products and ongoing work

### Products:

- [Aave Risk Monitoring and Alerting Platform](https://community.chaoslabs.xyz/aave/risk/overview)
- [Chaos Labs Asset Protection Tool](https://chaoslabs.xyz/posts/chaos-labs-asset-protection-tool)
- [Risk Oracles for Parameter Recommendations ](https://chaoslabs.xyz/solutions/risk)
- [GHO Risk Monitoring Dashboard ](https://community.chaoslabs.xyz/aave/risk/GHO)

### **Analyses and Proposals:**

- **CAPO Framework**
  - [Chaos Labs Correlated Asset Price Oracle Framework ](https://governance.aave.com/t/chaos-labs-correlated-asset-price-oracle-framework/16605)
- **New Deployments**
  - [[ARFC] Aave V3 Deployment on BNB Chain - #5 by ChaosLabs](https://governance.aave.com/t/arfc-aave-v3-deployment-on-bnb-chain/12609/5)
  - [[ARFC] Deployment of Aave on zkSync - #7 by ChaosLabs](https://governance.aave.com/t/arfc-deployment-of-aave-on-zksync/17937/7)
  - [[ARFC] Deploy a Lido Aave v3 Instance - #7 by ChaosLabs](https://governance.aave.com/t/arfc-deploy-a-lido-aave-v3-instance/18047/7)
  - [[ARFC] Deploy an Etherfi/Stablecoin Aave v3 Instance - #2 by ChaosLabs](https://governance.aave.com/t/arfc-deploy-an-etherfi-stablecoin-aave-v3-instance/18440/2)
- **Market Events**
  - [Chaos Labs Market Alert - High Price Volatility and Liquidations - 04/13/2024](https://governance.aave.com/t/chaos-labs-market-alert-high-price-volatility-and-liquidations-04-13-2024/17360)
  - [USDP Price Spike Impact - 04/16/2024](https://governance.aave.com/t/usdp-price-spike-impact-04-16-2024/17391)
  - [Chaos Labs Risk Report: Insights from Recent Market Events - 06/08/24](https://governance.aave.com/t/chaos-labs-risk-report-insights-from-recent-market-events-06-08-24/18554)
  - [Chaos Labs - Ethena's USDe and sUSDe Funding Rates - 08/06/24](https://governance.aave.com/t/chaos-labs-ethenas-usde-and-susde-funding-rates-08-06-24/18565)
- **GHO**
  - [[ARFC] GHO Cross-Chain Launch - #4 by ChaosLabs](https://governance.aave.com/t/arfc-gho-cross-chain-launch/17616/4)
- **V2 → V3 Migration and V2 Deprecation**
  - [[ARFC] Deprecation of Small-cap Stablecoins on V2 Ethereum](https://governance.aave.com/t/arfc-deprecation-of-small-cap-stablecoins-on-v2-ethereum/17484)
  - [[ARFC] Temporary Freeze of Long-Tail V2 Assets](https://governance.aave.com/t/arfc-temporary-freeze-of-long-tail-v2-assets/17403)
- **Risk Stewards**
  - [Risk Stewards posts](https://governance.aave.com/search?q=chaos%20labs%20Risk%20Stewards%20after%3A2024-01-01)

## Proposal

Chaos Labs offers a comprehensive risk management and optimization platform for Aave, covering the entire spectrum of Aave, including V2, V3, and GHO, across all current and future deployments.

Our strategies aim to secure protocol assets against market volatility, black swan events, liquidity attacks, and market manipulation. Our methodologies are rooted in an integrative approach, offering protocol robustness and protecting funds from market risks through dynamic risk parameter recommendations. We provide a holistic approach encompassing software and services to mitigate risks in volatile markets, countering economic attacks on the protocol and ensuring the secure preservation of user funds.

## Scope

### **Risk Parameter Optimization**

Using our state-of-the-art risk simulation platform, proprietary methodologies, and a highly skilled team of data scientists and researchers, we deliver in-depth analyses and strategic recommendations for optimizing risk parameters. Our cutting-edge simulations utilize real-time protocol dynamics and on-chain behaviors to rigorously stress-test the protocol, uncovering potential vulnerabilities and opportunities for enhancement. This advanced approach provides a detailed understanding of the factors influencing protocol health and stability, enabling us to offer data-driven recommendations that maximize protocol revenue while safeguarding user funds and mitigating risks.

Our coverage includes support for all Aave risk parameters, including Liquidation Thresholds, LTV, Liquidation Bonus, Supply and Borrow Caps, Debt Ceilings, and Interest Rate Curves.

### **Risk Oracles**

Enhance the capabilities of Edge Risk Oracles, developed by Chaos Labs, to better meet Aave’s specific requirements, enabling more efficient and dynamic adjustments to risk parameters. This will streamline the risk management process, minimize the need for manual interventions, and significantly improve the protocol’s operational efficiency and security.

Currently, this initiative is under [governance review ](https://governance.aave.com/t/arfc-aave-generalized-risk-stewards-agrs-activation/19178) for the Lido Instance, with plans to expand coverage to additional parameters and deployments in the future.

As part of this initiative, we will enhance our product by introducing a dashboard that monitors Risk Oracle updates, enabling the community to track historical changes and assess the impact of parameter optimizations over time.

### **Risk Monitoring and Alerting**

We offer real-time monitoring and alerting services through the [Chaos Labs Risk Monitoring Platform](https://community.chaoslabs.xyz/aave/risk/overview). These services allow users to assess ecosystem risk and protocol health at granular levels using dashboards and data visualizations. Users can drill into specific scenarios in which the protocol could be negatively impacted and receive alerts concerning significant changes to on-chain activities that could pose a risk or detriment to the protocol’s health.

As part of our commitment to delivering a world-class risk management solution for the DeFi ecosystem, we constantly iterate and improve the platform with additional features and enhancements. The Aave community will continue to gain access to the newest feature additions and enhancements continuously, allowing users to stay ahead of the curve and make informed decisions while optimizing their overall portfolio performance.

### Risk Stewards and Guardians

We act as Risk Stewards, carefully managing risk while adjusting supply and borrow caps according to predefined rules. This enables us to continually raise caps, fostering protocol growth without compromising safety. A current [governance proposal ](https://governance.aave.com/t/arfc-aave-generalized-risk-stewards-agrs-activation/19178) aims to expand the Risk Stewards’ authority to encompass a broader range of risk parameters, allowing for more agile and timely adjustments based on market conditions. Additionally, we serve as signers on the Aave Protocol Guardians, ensuring protocol security in critical situations, and as GHO Stewards.

### Deprecation of V2 and Migration to V3

Chaos Labs has spearheaded several community initiatives to deprecate the V2 markets and facilitate the transition to V3, as outlined in the ‘Background’ section.

As we progress with the deprecation plan and migration efforts, we are committed to continue allocating resources and offering the community recommendations for proactively adjusting V2 parameters. This includes updates to Liquidation Thresholds, Reserve Factors and enhancing the capital efficiency of V3 markets to ensure a seamless migration of positions from V2.

Given the extended nature of the transition to V3, it remains imperative to uphold proactive risk management for V2 during this transitional phase.

### **Protocol Growth**

Chaos Labs will provide integral support to the protocol growth initiatives through detailed market risk assessments and parameter recommendations for new asset listings and deployments.

As we onboard new assets and deployments, the Chaos team will seamlessly integrate them into our systems to facilitate continuous monitoring and parameter optimization. We uphold the same high standard for all assets and deployments, ensuring consistency and excellence across the board. Our goal is to provide unwavering support for the protocol’s expansion and sustainability.

### GHO

Chaos Labs is committed to the continued growth and safety of the stablecoin and will provide ongoing support, including:

- **Parameter Optimization** - We will conduct data-driven research and simulations to recommend optimizations for GHO-specific parameters, including Borrow rate, stkAAVE discount rate, bucket capacities, GSM, and DEX liquidity goals.
- **Ongoing Risk Management, Monitoring, and Analytics** - We will continue iterations on our unified risk monitoring and alerting platform for GHO across primary markets (Aave), including all facilitators and secondary markets (centralized and decentralized exchanges). Our risk management services include economic reviews of GHO and ecosystem adoption across primary and secondary markets, peg stability, GHO backing composition, and more.
- **Facilitator’s Risk Framework, Recommendations, and Monitoring** - We will continue to enhance our risk framework to consider potential facilitators and their corresponding GHO credit lines and provide ongoing risk analysis for potential and existing facilitators based on this framework.

## Chaos Team Support

As part of our services, we assign a dedicated protocol manager supported by our world-class team of researchers and data scientists to lead all risk-related communications and inquiries with the Aave community.

Our team support typically covers two main areas: ongoing management and incident response. In the event of any incidents or issues, our team will be on hand to provide timely and effective incident response, minimizing the potential impact on the protocol and its users.

**Ongoing and Proactive Risk Management**

This includes detailed analyses of new asset onboarding, assessing the potential risks and benefits of launching in new markets, and providing a thorough understanding of parameter recommendations, including qualitative data and position analysis.

**Incident Response**

This includes supporting various events, including liquidity changes, asset depegs, price volatilities, etc. Our team provides ongoing support in these events, including market monitoring and alerting, ad-hoc risk analysis, and recommendations on risk-mitigating actions.

Our team of experts brings a wealth of experience in risk management and data analysis, enabling us to provide the insights and recommendations necessary to navigate even the most challenging market conditions. By working closely with the community, we can provide the support and guidance necessary to promote Aave’s long-term success and sustainability.

## Communications:

- Our team will share our recommendations and analyses through dedicated governance forum discussions, maintaining transparency and facilitating effective communication with the community.
- We commit to providing a monthly update post, highlighting completed work and outlining our future focus areas.
- We are consistently available for community calls and regularly schedule check-up calls with Aave delegates. These calls primarily focus on addressing risk-related inquiries, offering insights into existing proposals, and gathering general feedback.

## Terms

- 12-month engagement, November 13th 2024-November 13th, 2025
- $2M, streamed linearly throughout the engagement.
  - $1,000,000 in GHO
  - $1,000,000 in aUSDT

## Specification

If this proposal is approved, a stream of the allocated budget will be activated, with a Chaos Labs-controlled account (`0xbC540e0729B732fb14afA240aA5A047aE9ba7dF0`) as the recipient.

Regarding technical implementation, the AIP will call the `createStream()` method of the `IAaveEcosystemReserveController` interface to create a stream of 1,000,000 aUSDT and 1,000,000 GHO for a 12-month duration.

## References

- Implementation: [AaveV3Ethereum](https://github.com/bgd-labs/aave-proposals-v3/blob/17f32f018e6b5d8cba81e1c37485e7636c25be86/src/20241012_AaveV3Ethereum_ChaosLabsAaveRiskManagementServiceRenewal/AaveV3Ethereum_ChaosLabsAaveRiskManagementServiceRenewal_20241012.sol)
- Tests: [AaveV3Ethereum](https://github.com/bgd-labs/aave-proposals-v3/blob/17f32f018e6b5d8cba81e1c37485e7636c25be86/src/20241012_AaveV3Ethereum_ChaosLabsAaveRiskManagementServiceRenewal/AaveV3Ethereum_ChaosLabsAaveRiskManagementServiceRenewal_20241012.t.sol)
- [Snapshot](https://snapshot.org/#/aave.eth/proposal/0xa8ec5cf2568691144861b38af1b2cef4f95d33d0912fea28438132cabf4b6c28)
- [Discussion](https://governance.aave.com/t/arfc-chaos-labs-aave-risk-management-service-renewal/19306)

## Copyright

Copyright and related rights waived via [CC0](https://creativecommons.org/publicdomain/zero/1.0/).
